@@ -1,5 +1,5 @@
 from ._version import __version__
-from .base import MedicalImage, NeuroImage
+from .base import MedicalImage
 from .misc import (  # noqa: F401
     Analyze,
 )
@@ -25,10 +25,10 @@ from .diffusion import (
     NiftiGzXB,
 )
 from .dicom import (  # noqa: F401
-    DicomFile,
-    SiemensDicomFile,
-    Dicom,
-    SiemensDicom,
+    DicomCollection,
+    DicomDir,
+    DicomSet,
+    # SiemensDicomDir,
 )
 from .raw import (  # noqa: F401
     ListMode,
